Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetUserInt ¶
GetUserInt reads input from a scanner and returns the result if it is an int in the range low <= x <= high. Prompts the user to attempt again if input cannot be intepreted as an int in given range.
Types ¶
Click to show internal directories.
Click to hide internal directories.